"""
Oferta y Demanda Agregada - Modelo OA-DA.

TODO: Implementar en versiones futuras:
- Demanda agregada
- Oferta agregada de corto plazo
- Oferta agregada de largo plazo
- Equilibrio de corto y largo plazo
- Curva de Phillips
- Ley de Okun
"""

# Placeholder
pass